@@ -26,7 +26,7 @@ class DBConn:
         self.encoding = encoding
         self.lib_dir = lib_dir
         
-        self.runtp = ThreadPool(1)
+        self.runtp = ThreadPool(1, save_result=True)
         self.dbpool = None
         
         self.config = {
