@@ -4,7 +4,7 @@ from tools_hjh.DBConn import DBConn
 from tools_hjh.DBConn import QueryResults
 from tools_hjh.MemoryDB import MemoryDB
 from tools_hjh.Tools import line_merge_align, locatdate, merge_spaces, \
-    analysis_hosts, locattime
+    analysis_hosts, locattime, remove_leading_space
 
 
 def main():
@@ -426,6 +426,36 @@ class OracleTools:
         size = size.replace('\n', '').strip()
         return size, rs_list, mess
     
+    @staticmethod   
+    def expdp_job(sid, users=''):
+        date_str = locatdate()
+        if users == '':
+            sh = '''
+                source ~/.bash_profile
+                export ORACLE_SID=''' + sid + '''
+                expdp \\'/ as sysdba\\' \\
+                compression=all \\
+                cluster=n \\
+                parallel=8 \\
+                full=y \\
+                directory=DUMP \\
+                dumpfile=''' + sid + '_' + date_str + '''.dmp
+            '''
+        else:
+            sh = '''
+                source ~/.bash_profile
+                export ORACLE_SID=''' + sid + '''
+                expdp \\'/ as sysdba\\' \\
+                compression=all \\
+                cluster=n \\
+                parallel=8 \\
+                schemas=''' + users + ''' \\
+                directory=DUMP \\
+                dumpfile=''' + sid + '_' + date_str + '''.dmp
+            '''  
+        
+        return remove_leading_space(sh)
+    
     @staticmethod  
     def expdp(src_host_conn, src_dba_conn, src_ora_sid, src_ora_user='', dump_tmp_py='/tmp/oracle_dump_py'):
         if src_ora_user == '':
